==> esup-canal-intranet-3.10.zip: CIntranet-3.10/source/org/esupportail/portal/channels/CIntranet/actions/intranet/OrderFolder.java <==
package org.esupportail.portal.channels.CIntranet.actions.intranet;

import java.util.Hashtable;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.esupportail.portal.channels.CIntranet.data.DataControler;
import org.esupportail.portal.channels.CIntranet.data.DataException;
import org.esupportail.portal.channels.CIntranet.security.Security;
import org.esupportail.portal.utils.channels.FrameWorkException;
import org.esupportail.portal.utils.channels.MainChannel;
import org.esupportail.portal.utils.channels.plugins.Message;
import org.esupportail.portal.utils.channels.plugins.MessageBean;
import org.jasig.portal.ChannelRuntimeData;
import org.jasig.portal.PortalException;

/**
 * OrderFolder<br>
 * <br>
 * Cette classe prend en charge la modification d'ordre des dossiers<br>
 * <br>
 * (c)Copyright <a href="http://www.esup-portail.org">ESup-Portail 2004</a><br>
 * @author <a href="mailto:mathieu.larchet@univ-nancy2.fr">Mathieu Larchet</a>
 * @version $Revision: 1.1.2.1 $
 * 
 */
public class OrderFolder extends AbstractAction {

    protected static Log log = LogFactory.getLog(OrderFolder.class);
    
    /**
     * Constructeur
     * @param mainChannel La channel principale
     */
    public OrderFolder(MainChannel mainChannel) {
        super(mainChannel);
    }
    
    /**
     * Indique le niveau requis pour raliser cette action
     * Implements AbstractAction.getLevel() method
     * @return level Le niveau requis pour accder  cette action
     */
    public int getLevel() {
        return Security.ED_VAL;
    }
    
    /**
     * Etape 2/4 du cycle de vie de la SubChannel
     * Modifie l'ordre d'un dossier
     * Override SubChannel.init() method
     * @param rd Les runtimeData
     * @return Boolean TRUE si tout se passe bien, FALSE sinon
     * @throws PortalException
     * @throws FrameWorkException
     */
    public Boolean init(ChannelRuntimeData rd) throws PortalException, FrameWorkException {
        super.init(rd);
        if(super.initialize(rd).equals(Boolean.FALSE)) {
            return Boolean.FALSE;
        }
        if(log.isDebugEnabled()) {
            log.debug("OrderFolder::init()");
        }
		String id = runtimeData.getParameter("id");
		String rank = runtimeData.getParameter("rank");
		String direction = runtimeData.getParameter("dir");
		if(id == null || rank == null || direction == null) {
			log.error("OrderFolder::init() : Erreur d'acc\u00E8s \u00E0 la page");
			Message.message(getMainChannel(), getRuntimeData(), new MessageBean("Erreur d'acc\u00E8s \u00E0 la page"), "intranet");		
			return Boolean.FALSE;
		}
		int order = Integer.parseInt(rank);
        DataControler data = new DataControler();
        try {
			if(direction.equals("up")) {
			    data.swapFolders(folderid, id, order, order - 1);
			}
			else {
			    data.swapFolders(folderid, id, order, order + 1);
			}
		}
        catch(DataException e) {
            log.error("OrderFolder::init() : DataException :\n" + e);
            Hashtable parameters = new Hashtable();
            parameters.put("folder", folderid);
            Message.message(getMainChannel(), getRuntimeData(), new MessageBean(e.getMessage()), "viewfolder", parameters);
            return Boolean.FALSE;
        }
        getRuntimeData().setParameter("folder", folderid);
        getMainChannel().redirect(getRuntimeData(), "viewfolder");
        return Boolean.TRUE;
    }
}

==> esup-canal-intranet-3.21.zip: CIntranet-3.21/source/org/esupportail/portal/channels/CIntranet/actions/intranet/OrderFolder.java <==
package org.esupportail.portal.channels.CIntranet.actions.intranet;

import java.util.Hashtable;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.esupportail.portal.channels.CIntranet.data.DataControler;
import org.esupportail.portal.channels.CIntranet.data.DataException;
import org.esupportail.portal.channels.CIntranet.security.Security;
import org.esupportail.portal.utils.channels.FrameWorkException;
import org.esupportail.portal.utils.channels.MainChannel;
import org.esupportail.portal.utils.channels.plugins.Message;
import org.esupportail.portal.utils.channels.plugins.MessageBean;
import org.jasig.portal.ChannelRuntimeData;
import org.jasig.portal.PortalException;

/**
 * OrderFolder<br>
 * <br>
 * Cette classe prend en charge la modification d'ordre des dossiers<br>
 * <br>
 * (c)Copyright <a href="http://www.esup-portail.org">ESup-Portail 2004</a><br>
 * @author <a href="mailto:mathieu.larchet@univ-nancy2.fr">Mathieu Larchet</a>
 * @version $Revision: 1.1.2.2 $
 * 
 */
public class OrderFolder extends AbstractAction {

    protected static Log log = LogFactory.getLog(OrderFolder.class);
    
    /**
     * Constructeur
     * @param mainChannel La channel principale
     */
    public OrderFolder(MainChannel mainChannel) {
        super(mainChannel);
    }
    
    /**
     * Indique le niveau requis pour raliser cette action
     * Implements AbstractAction.getLevel() method
     * @return level Le niveau requis pour accder  cette action
     */
    public int getLevel() {
        return Security.AUT_MOD;
    }
    
    /**
     * Etape 2/4 du cycle de vie de la SubChannel
     * Modifie l'ordre d'un dossier
     * Override SubChannel.init() method
     * @param rd Les runtimeData
     * @return Boolean TRUE si tout se passe bien, FALSE sinon
     * @throws PortalException
     * @throws FrameWorkException
     */
    public Boolean init(ChannelRuntimeData rd) throws PortalException, FrameWorkException {
        super.init(rd);
        if(super.initialize(rd).equals(Boolean.FALSE)) {
            return Boolean.FALSE;
        }
        if(log.isDebugEnabled()) {
            log.debug("OrderFolder::init()");
        }
		String id = runtimeData.getParameter("id");
		String rank = runtimeData.getParameter("rank");
		String direction = runtimeData.getParameter("dir");
		if(id == null || rank == null || direction == null) {
			log.error("OrderFolder::init() : Erreur d'acc\u00E8s \u00E0 la page");
			Message.message(getMainChannel(), getRuntimeData(), new MessageBean("Erreur d'acc\u00E8s \u00E0 la page"), "intranet");		
			return Boolean.FALSE;
		}
		int order = Integer.parseInt(rank);
        DataControler data = new DataControler();
        try {
			if(direction.equals("up")) {
			    data.swapFolders(folderid, id, order, order - 1);
			}
			else {
			    data.swapFolders(folderid, id, order, order + 1);
			}
		}
        catch(DataException e) {
            log.error("OrderFolder::init() : DataException :\n" + e);
            Hashtable parameters = new Hashtable();
            parameters.put("folder", folderid);
            Message.message(getMainChannel(), getRuntimeData(), new MessageBean(e.getMessage()), "viewfolder", parameters);
            return Boolean.FALSE;
        }
        getRuntimeData().setParameter("folder", folderid);
        getMainChannel().redirect(getRuntimeData(), "viewfolder");
        return Boolean.TRUE;
    }
}
